#ifndef __CDW_TMP_FILES_H
#define __CDW_TMP_FILES_H


/* list of files to be put on CD */
#define FILELIST_SIZE 100
char *filelist[FILELIST_SIZE];

int filelist_to_file(void);
int filelist_add(char *path);
int filelist_remove(char *path);
int filelist_items(char ***filetable);
int filelist_empty(void);
void filelist_init(void);
void filelist_clean(void);

int tmpfiles_init(void);

#endif /* __CDW_TMP_FILES_H */
